@@ -4,6 +4,7 @@
 
 #include <vector>
 #include <iostream>
+#include <QMessageBox>
 
 #include "OverlayWidget.h"
 #include "SoundPlayer.h"
@@ -13,6 +14,7 @@
 using namespace std;
 
 void CameraThread::run() {
+    exitLock.lock();
     if (!overlay) {
         printf("No overlay attached to camera thread, exiting!\n");
         return;
@@ -68,11 +70,12 @@ void CameraThread::run() {
         while (FCam::getNextEvent(&e)) {
             switch(e.type) {
             case FCam::Event::Error:
-                printf("FCam Error: %s\n", e.description.c_str());
-                if (e.data == FCam::Event::DriverLockedError ||
-                    e.data == FCam::Event::DriverMissingError) {
-                    printf("Terminating\n");
+                printf("FCam Error: %s\n", e.description.c_str());                
+                if (e.data == FCam::Event::DriverLockedError || e.data == FCam::Event::DriverMissingError) {                
+                    emit panic(e);
                     sensor.stop();
+                    exitLock.lock();
+                    printf("Terminating\n");
                     return;
                 }
                 break;
